.. Kamaki documentation master file, created by
   sphinx-quickstart on Tue Nov 29 15:15:50 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
 
Kamaki project documentation
============================

.. image:: /images/kamaki-logo.png

./kamaki is a simple, yet intuitive, multipurpose, interactive command-line tool and client API for managing clouds.

As a develpment API is an initial implementation of the OpenStack Compute API, v1.1, with custom extensions specific to the `Synnefo IaaS <http://synnefo.org/>`_ cloud management software.

./kamaki is open source and released under a 2-clause BSD License.


Contents:
*********

.. toctree::
   :maxdepth: 2
   :numbered:
   :glob:
   
   overview
   installation
   setup
   usage
   commands
   devguide


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
